import { Carousel, CarouselContent, CarouselItem } from '@/components/ui/carousel';
import { ChevronDown } from 'lucide-react';
import { useEffect, useState } from 'react';

const heroImages = [
    {
        url: 'https://plus.unsplash.com/premium_photo-1666254114402-cd16bc302aea?q=80&w=2071&auto=format&fit=crop&ixlib=rb-4.1.0&ixid=M3wxMjA3fDB8MHxwaG90by1wYWdlfHx8fGVufDB8fHx8fA%3D%3D',
        title: 'Discover the Beauty of Sri Lanka',
    },
    {
        url: 'https://images.unsplash.com/photo-1580910527739-556eb89f9d65?q=80&w=1974&auto=format&fit=crop&ixlib=rb-4.1.0&ixid=M3wxMjA3fDB8MHxwaG90by1wYWdlfHx8fGVufDB8fHx8fA%3D%3D',
        title: 'Explore the Pearl of the Indian Ocean',
    },
    {
        url: 'https://images.unsplash.com/photo-1566838345788-db81125cef85?q=80&w=1975&auto=format&fit=crop&ixlib=rb-4.1.0&ixid=M3wxMjA3fDB8MHxwaG90by1wYWdlfHx8fGVufDB8fHx8fA%3D%3D',
        title: 'Adventure Awaits in Sri Lanka',
    },
];

const Hero = () => {
    const [currentSlide, setCurrentSlide] = useState(0);
    const [api, setApi] = useState<any>(null);

    const scrollToTours = () => {
        const toursSection = document.getElementById('tours');
        if (toursSection) {
            toursSection.scrollIntoView({ behavior: 'smooth' });
        }
    };

    useEffect(() => {
        if (!api) return;

        const interval = setInterval(() => {
            api.scrollNext();
            setCurrentSlide((prev) => (prev + 1) % heroImages.length);
        }, 10500000);

        return () => clearInterval(interval);
    }, [api]);

    return (
        <>
            <style>{`
                @keyframes slideInUp {
                    0% { transform: translateY(30px); opacity: 0; }
                    100% { transform: translateY(0); opacity: 1; }
                }
                
                @keyframes fadeIn {
                    0% { opacity: 0; }
                    100% { opacity: 1; }
                }

                .hero-title {
                    color: white;
                    text-shadow: 
                        -2px -1px 0 #92C743,
                        1px -1px 0 #92C743,
                        -1px 1px 0 #92C743,
                        1px 1px 0 #92C743,
                        0 0 10px rgba(0, 0, 0, 0.6);
                    animation: slideInUp 0.8s ease-out;
                    font-weight: 700;
                    letter-spacing: -0.01em;
                    line-height: 1.2;
                    font-size: 90px;
                }

                .hero-description {
                    animation: fadeIn 1s ease-out 0.4s both;
                    color: #f0f0f0;
                    text-shadow: 1px 1px 2px rgba(0, 0, 0, 0.8);
                    font-weight: 300;
                    letter-spacing: 0.5px;
                    line-height: 1.6;
                    font-size: 30px;
                    width: 80%;
                }
                @media (max-width: 993px) {
                    .hero-title {
                        font-size: 48px  !important;
                    }
                    .hero-description {
                        font-size: 28px  !important;
                    }
                }

                @media (max-width: 768px) {
                    .tour-image {
                        height: 250px;
                    }
                    .hero-title {
                        text-shadow: 
                            -1px -1px 0 #92C743,
                            1px -1px 0 #92C743,
                            -1px 1px 0 #92C743,
                            1px 1px 0 #92C743,
                            0 0 8px rgba(0, 0, 0, 0.8);
                        font-size: 48px !important;
                    }
                    .hero-description {
                        font-size: 18px !important;
                    }
                    #home{
                        height: 500px;
                    }
                    #slide{
                        height: 500px;
                    }
                }
            `}</style>

            <section id="home" className="hero-section relative h-screen overflow-hidden">
                <Carousel className="h-screen w-full" setApi={setApi} opts={{ loop: true }}>
                    <CarouselContent className="h-screen">
                        {heroImages.map((image, index) => (
                            <CarouselItem key={index} className="relative h-screen">
                                {/* Background image */}
                                <div className="bg-opacity-5 absolute inset-0 z-10 bg-black opacity-50"></div>

                                <img src={image.url} alt="Background" className="z-0 h-screen w-full object-cover" />

                                {/* Overlay */}

                                {/* Text Content */}
                                {index === currentSlide && (
                                    <div className="absolute inset-0 z-20 flex flex-col items-center justify-center text-center" id="slide">
                                        <h1 className="hero-title mb-6 text-5xl font-bold md:text-6xl lg:text-7xl w-80 md:w-full ">{image.title}</h1>
                                        <p className="hero-description max-w-3xl text-lg md:text-xl">
                                            Experience the magic of Sri Lanka with our expertly curated tours and unforgettable adventures.
                                        </p>
                                    </div>
                                )}
                            </CarouselItem>
                        ))}
                    </CarouselContent>
                </Carousel>

                <div className="absolute right-0 bottom-10 left-0 z-20 animate-bounce" style={{ display: 'flex', justifyContent: 'center' }}>
                    <button onClick={scrollToTours} className="transform text-white transition-all duration-300 hover:scale-110 hover:text-[#92C743]">
                        <ChevronDown size={36} className="mx-auto drop-shadow-lg" />
                    </button>
                </div>
            </section>
        </>
    );
};

export default Hero;
